@@ -43,8 +43,8 @@ static GSList *refd_plugins = NULL;
 
 static GType go_component_engine_service_get_type (void);
 
-typedef PluginServiceGObjectLoader GOComponentEngineService;
-typedef PluginServiceGObjectLoaderClass GOComponentEngineServiceClass;
+typedef GOPluginServiceGObjectLoader GOComponentEngineService;
+typedef GOPluginServiceGObjectLoaderClass GOComponentEngineServiceClass;
 
 static GHashTable *pending_engines = NULL;
 static GHashTable *mime_types = NULL;
@@ -59,7 +59,7 @@ go_component_engine_service_get_description (GOPluginService * service)
 }
 
 static void
-go_component_engine_service_class_init (PluginServiceGObjectLoaderClass *
+go_component_engine_service_class_init (GOPluginServiceGObjectLoaderClass *
 					gobj_loader_class)
 {
 	GOPluginServiceClass *ps_class = GPS_CLASS (gobj_loader_class);
@@ -83,12 +83,12 @@ GType go_component_type_service_get_type (void);
 
 typedef struct
 {
-	PluginServiceSimple base;
+	GOPluginServiceSimple base;
 
 	GSList *mime_types;
 } GOComponentTypeService;
 
-typedef PluginServiceSimpleClass GOComponentTypeServiceClass;
+typedef GOPluginServiceSimpleClass GOComponentTypeServiceClass;
 
 static GObjectClass *component_type_parent_klass;
 char const *GOPriorityName[] = {
@@ -108,7 +108,7 @@ go_mime_type_free (GOMimeType * mime_type)
 
 static void
 go_component_type_service_read_xml (GOPluginService * service, xmlNode * tree,
-				    ErrorInfo ** ret_error)
+				    GOErrorInfo ** ret_error)
 {
 	xmlNode *ptr;
 
@@ -205,16 +205,16 @@ GSF_CLASS (GOComponentTypeService, go_component_type_service,
 	   go_component_type_service_class_init,
 	   go_component_type_service_init, GO_TYPE_PLUGIN_SERVICE_SIMPLE)
 /***************************************************************************/
-     void goc_plugin_services_init (void)
+     void _goc_plugin_services_init (void)
 {
-	plugin_service_define ("component_engine",
+	go_plugin_service_define ("component_engine",
 			       &go_component_engine_service_get_type);
-	plugin_service_define ("component_type",
+	go_plugin_service_define ("component_type",
 			       &go_component_type_service_get_type);
 }
 
 void
-goc_plugin_services_shutdown (void)
+_goc_plugin_services_shutdown (void)
 {
 	g_slist_foreach (refd_plugins, (GFunc) go_plugin_use_unref, NULL);
 	g_slist_foreach (refd_plugins, (GFunc) g_object_unref, NULL);
@@ -291,7 +291,7 @@ go_component_new_by_mime_type (char const *mime_type)
 	type = g_type_from_name (mtype->component_type_name);
 	if (type == 0)
 	{
-		ErrorInfo *err = NULL;
+		GOErrorInfo *err = NULL;
 		GOPluginService *service =
 			pending_engines
 			? g_hash_table_lookup (pending_engines,
@@ -303,13 +303,13 @@ go_component_new_by_mime_type (char const *mime_type)
 
 		g_return_val_if_fail (!service->is_loaded, NULL);
 
-		plugin_service_load (service, &err);
+		go_plugin_service_load (service, &err);
 		type = g_type_from_name (mtype->component_type_name);
 
 		if (err != NULL)
 		{
-			error_info_print (err);
-			error_info_free (err);
+			go_error_info_print (err);
+			go_error_info_free (err);
 		}
 
 		g_return_val_if_fail (type != 0, NULL);
@@ -317,7 +317,7 @@ go_component_new_by_mime_type (char const *mime_type)
 		/*
 		 * The plugin defined a gtype so it must not be unloaded.
 		 */
-		plugin = plugin_service_get_plugin (service);
+		plugin = go_plugin_service_get_plugin (service);
 		refd_plugins = g_slist_prepend (refd_plugins, plugin);
 		g_object_ref (plugin);
 		go_plugin_use_ref (plugin);
