@@ -22,9 +22,7 @@
 #ifndef GOG_DATA_SET_H
 #define GOG_DATA_SET_H
 
-#include <goffice/graph/goffice-graph.h>
-#include <goffice/data/goffice-data.h>
-#include <glib-object.h>
+#include <goffice/goffice.h>
 
 G_BEGIN_DECLS
 
