@@ -47,7 +47,6 @@ static GObjectClass *error_bar_parent_klass;
 #include <goffice/gtk/goffice-gtk.h>
 #include <goffice/gtk/go-pixbuf.h>
 #include <goffice/gtk/go-color-selector.h>
-#include <glade/glade-xml.h>
 
 typedef struct {
 	GogSeries 	   *series;
@@ -135,7 +134,7 @@ cb_display_changed (GtkComboBox *combo, GogErrorBarEditor *editor)
 static void
 cb_type_changed (GtkWidget *w, GogErrorBarEditor *editor)
 {
-	GladeXML *gui = GLADE_XML (g_object_get_data (G_OBJECT (w), "gui"));
+	GtkBuilder *gui = GTK_BUILDER (g_object_get_data (G_OBJECT (w), "gui"));
 	gpointer data;
 	GogDataset *set;
 	GogDataAllocator *dalloc;
@@ -156,10 +155,10 @@ cb_type_changed (GtkWidget *w, GogErrorBarEditor *editor)
 			gtk_widget_destroy (GTK_WIDGET(data));
 		g_object_set_data (G_OBJECT (w), "plus", NULL);
 		g_object_set_data (G_OBJECT (w), "minus", NULL);
-		gtk_widget_hide (glade_xml_get_widget (gui, "values_box"));
-		gtk_widget_hide (glade_xml_get_widget (gui, "style_box"));
+		gtk_widget_hide (go_gtk_builder_get_widget (gui, "values_box"));
+		gtk_widget_hide (go_gtk_builder_get_widget (gui, "style_box"));
 	} else {
-		GtkWidget *table = glade_xml_get_widget (gui, "values_table");
+		GtkWidget *table = go_gtk_builder_get_widget (gui, "values_table");
 		if (!editor->bar) {
 			editor->bar = g_object_new (GOG_TYPE_ERROR_BAR, NULL);
 			editor->bar->style->line.color = editor->color;
@@ -189,8 +188,8 @@ cb_type_changed (GtkWidget *w, GogErrorBarEditor *editor)
 			gtk_table_attach (GTK_TABLE (table), al, 1, 2, 1, 2, GTK_FILL | GTK_EXPAND, 0, 0, 0);
 			g_object_set_data (G_OBJECT (w), "minus", al);
 		}
-		gtk_widget_show_all (glade_xml_get_widget (gui, "values_box"));
-		gtk_widget_show (glade_xml_get_widget (gui, "style_box"));
+		gtk_widget_show_all (go_gtk_builder_get_widget (gui, "values_box"));
+		gtk_widget_show (go_gtk_builder_get_widget (gui, "style_box"));
 	}
 	gog_object_request_update (GOG_OBJECT (editor->series));
 }
@@ -202,7 +201,7 @@ gog_error_bar_prefs (GogSeries *series,
 		     GogDataAllocator *dalloc,
 		     GOCmdContext *cc)
 {
-	GladeXML *gui;
+	GtkBuilder *gui;
 	GtkWidget *w, *bar_prefs;
 	GtkTable *style_table, *values_table;
 	GtkWidget *combo;
@@ -233,30 +232,30 @@ gog_error_bar_prefs (GogSeries *series,
 	}
 	set = GOG_DATASET (series);
 
-	gui = go_glade_new ("gog-error-bar-prefs.glade", "gog_error_bar_prefs", GETTEXT_PACKAGE, cc);
+	gui = go_gtk_builder_new ("gog-error-bar-prefs.ui", GETTEXT_PACKAGE, cc);
 
 	/* Style properties */
 
 	/* Width */
-	w = glade_xml_get_widget (gui, "width");
+	w = go_gtk_builder_get_widget (gui, "width");
 	gtk_spin_button_set_value (GTK_SPIN_BUTTON (w), editor->width);
 	g_signal_connect (gtk_spin_button_get_adjustment (GTK_SPIN_BUTTON (w)),
 		"value_changed",
 		G_CALLBACK (cb_width_changed), editor);
 	
 	/* Line width */
-	w = glade_xml_get_widget (gui, "line_width");
+	w = go_gtk_builder_get_widget (gui, "line_width");
 	gtk_spin_button_set_value (GTK_SPIN_BUTTON (w), editor->line_width);
 	g_signal_connect (gtk_spin_button_get_adjustment (GTK_SPIN_BUTTON (w)),
 		"value_changed",
 		G_CALLBACK (cb_line_width_changed), editor);
 
-	style_table = GTK_TABLE (glade_xml_get_widget (gui, "style_table"));
+	style_table = GTK_TABLE (gtk_builder_get_object (gui, "style_table"));
 
 	/* Color */
 	w = go_color_selector_new (editor->color, RGBA_BLACK, "error-bar");
 	gtk_label_set_mnemonic_widget (
-		GTK_LABEL (glade_xml_get_widget (gui, "color_label")), w);
+		GTK_LABEL (gtk_builder_get_object (gui, "color_label")), w);
 	g_signal_connect (G_OBJECT (w),
 		"activate",
 		G_CALLBACK (cb_color_changed), editor);
@@ -294,18 +293,18 @@ gog_error_bar_prefs (GogSeries *series,
 	g_signal_connect (G_OBJECT (combo), "changed", G_CALLBACK (cb_display_changed), editor);
 	
 	/* Category property*/
-	w = glade_xml_get_widget (gui, "category_combo");
+	w = go_gtk_builder_get_widget (gui, "category_combo");
 	gtk_combo_box_set_active (GTK_COMBO_BOX (w), (editor->bar)? (int) editor->bar->type: 0);
-	g_object_set_data_full (G_OBJECT (w), "gui", gui, (GDestroyNotify)g_object_unref);
+	g_object_set_data (G_OBJECT (w), "gui", gui);
 	g_object_set_data (G_OBJECT (w), "allocator", dalloc);
 	g_signal_connect (G_OBJECT (w), "changed", G_CALLBACK (cb_type_changed), editor);
 
 	/* Value properties */
-	bar_prefs = glade_xml_get_widget (gui, "gog_error_bar_prefs");
+	bar_prefs = go_gtk_builder_get_widget (gui, "gog_error_bar_prefs");
 	g_signal_connect (bar_prefs, "destroy", G_CALLBACK (cb_destroy), editor);
 	gtk_widget_show_all (bar_prefs);
 
-	values_table = GTK_TABLE (glade_xml_get_widget (gui, "values_table"));
+	values_table = GTK_TABLE (gtk_builder_get_object (gui, "values_table"));
 	if (editor->bar) {
 		GtkWidget* al = GTK_WIDGET (gog_data_allocator_editor (dalloc, set, editor->bar->error_i, GOG_DATA_VECTOR));
 		gtk_widget_show (al);
@@ -316,9 +315,10 @@ gog_error_bar_prefs (GogSeries *series,
 		gtk_table_attach (values_table, al, 1, 2, 1, 2, GTK_FILL | GTK_EXPAND, 0, 0, 0);
 		g_object_set_data (G_OBJECT (w), "minus", al);
 	} else {
-		gtk_widget_hide (glade_xml_get_widget (gui, "values_box"));
-		gtk_widget_hide (glade_xml_get_widget (gui, "style_box"));
+		gtk_widget_hide (go_gtk_builder_get_widget (gui, "values_box"));
+		gtk_widget_hide (go_gtk_builder_get_widget (gui, "style_box"));
 	}
+	g_signal_connect (G_OBJECT (bar_prefs), "destroy", G_CALLBACK (g_object_unref), gui);
 
 	return GTK_WIDGET(bar_prefs);
 }
