@@ -21,36 +21,10 @@
 #ifndef GOG_OBJECT_H
 #define GOG_OBJECT_H
 
-#include <goffice/graph/goffice-graph.h>
-#include <goffice/app/goffice-app.h>
-#include <glib-object.h>
-#ifdef GOFFICE_WITH_GTK
-#include <gtk/gtk.h>
-#endif
+#include <goffice/goffice.h>
 
 G_BEGIN_DECLS
 
-typedef struct {
-	char const	*label;		/* label for notebook page */
-	gpointer 	 widget;	/* GtkWidget* */	
-} GogEditorPage;
-
-typedef struct {
-	unsigned	*store_page;		/* pointer to a place for storing last edited page */
-	GSList		*pages;			/* GogEditorPage */
-	GData		*registered_widgets;
-} GogEditor;
-
-GogEditor	*gog_editor_new 		  (void);
-void 		 gog_editor_free 		  (GogEditor *editor);
-void		 gog_editor_add_page 		  (GogEditor *editor, gpointer widget, char const *label);
-void 		 gog_editor_set_store_page  	  (GogEditor *editor, unsigned *store_page);
-#ifdef GOFFICE_WITH_GTK
-void 		 gog_editor_register_widget 	  (GogEditor *editor, GtkWidget *widget);
-GtkWidget  	*gog_editor_get_registered_widget (GogEditor *editor, char const *name);
-GtkWidget 	*gog_editor_get_notebook 	  (GogEditor *editor);
-#endif
-
 typedef enum {
 	GOG_OBJECT_NAME_BY_ROLE	 = 1,
 	GOG_OBJECT_NAME_BY_TYPE  = 2,
@@ -116,7 +90,7 @@ typedef struct {
 	void	     (*parent_changed)	(GogObject *obj, gboolean was_set);
 	char const  *(*type_name)	(GogObject const *obj);
 	void	     (*populate_editor)	(GogObject *obj, 
-					 GogEditor *editor,
+					 GOEditor *editor,
 					 GogDataAllocator *dalloc, 
 					 GOCmdContext *cc);
 	void	     (*document_changed)(GogObject *obj, GODoc *doc);
@@ -132,12 +106,12 @@ typedef struct {
 	void (*update_editor)	   (GogObject *obj);
 } GogObjectClass;
 
-#define GOG_OBJECT_TYPE		(gog_object_get_type ())
-#define GOG_OBJECT(o)		(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_OBJECT_TYPE, GogObject))
-#define IS_GOG_OBJECT(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_OBJECT_TYPE))
-#define GOG_OBJECT_CLASS(k)	(G_TYPE_CHECK_CLASS_CAST ((k), GOG_OBJECT_TYPE, GogObjectClass))
-#define IS_GOG_OBJECT_CLASS(k)	(G_TYPE_CHECK_CLASS_TYPE ((k), GOG_OBJECT_TYPE))
-#define GOG_OBJECT_GET_CLASS(o)	(G_TYPE_INSTANCE_GET_CLASS ((o), GOG_OBJECT_TYPE, GogObjectClass))
+#define GOG_TYPE_OBJECT		(gog_object_get_type ())
+#define GOG_OBJECT(o)		(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_TYPE_OBJECT, GogObject))
+#define GOG_IS_OBJECT(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_TYPE_OBJECT))
+#define GOG_OBJECT_CLASS(k)	(G_TYPE_CHECK_CLASS_CAST ((k), GOG_TYPE_OBJECT, GogObjectClass))
+#define GOG_IS_OBJECT_CLASS(k)	(G_TYPE_CHECK_CLASS_TYPE ((k), GOG_TYPE_OBJECT))
+#define GOG_OBJECT_GET_CLASS(o)	(G_TYPE_INSTANCE_GET_CLASS ((o), GOG_TYPE_OBJECT, GogObjectClass))
 
 #define GOG_PARAM_FORCE_SAVE	(1 << (G_PARAM_USER_SHIFT+1))	/* even if the value == default */
 #define GOG_PARAM_POSITION	(1 << (G_PARAM_USER_SHIFT+2))	/* position parameters */
