@@ -20,24 +20,11 @@
  */
 
 #include <goffice/goffice-config.h>
-#include <goffice/graph/gog-series-impl.h>
-#include <goffice/graph/gog-data-allocator.h>
-#include <goffice/graph/gog-plot-impl.h>
-#include <goffice/graph/gog-theme.h>
-#include <goffice/utils/go-style.h>
-#include <goffice/graph/gog-error-bar.h>
-#include <goffice/data/go-data.h>
-#include <goffice/utils/go-persist.h>
-#include <goffice/utils/go-style.h>
-#include <goffice/utils/go-styled-object.h>
+#include <goffice/goffice.h>
 
 #include <gsf/gsf-impl-utils.h>
 #include <glib/gi18n-lib.h>
 
-#ifdef GOFFICE_WITH_GTK
-#include <goffice/gtk/goffice-gtk.h>
-#endif
-
 #include <string.h>
 
 /* Keep in sync with GogSeriesFillType enum */
@@ -418,9 +405,9 @@ cb_show_in_legend (GtkToggleButton *b, GObject *series)
 static void
 cb_line_interpolation_changed (GtkComboBox *box, GogSeries *series)
 {
-	GladeXML *gui = g_object_get_data (G_OBJECT (box), "gui");
+	GtkBuilder *gui = g_object_get_data (G_OBJECT (box), "gui");
 	GtkWidget *widget = GTK_WIDGET (g_object_get_data (G_OBJECT(box), "skip-button"));
-	GtkWidget *table = glade_xml_get_widget (gui, "clamps-table");
+	GtkWidget *table = go_gtk_builder_get_widget (gui, "clamps-table");
 	series->interpolation = gtk_combo_box_get_active (box);
 	gtk_widget_set_sensitive (widget, !go_line_interpolation_auto_skip (series->interpolation));
 	widget = GTK_WIDGET (g_object_get_data (G_OBJECT(box), "fill-type"));
@@ -530,17 +517,17 @@ gog_series_populate_editor (GogObject *gobj,
 
 	box = go_editor_get_registered_widget (editor, "line_box");
 	if (series_class->has_interpolation && box != NULL) {
-		GladeXML *gui;
+		GtkBuilder *gui;
 		GtkWidget *widget;
 
-		gui = go_glade_new ("gog-series-prefs.glade", "interpolation_prefs", GETTEXT_PACKAGE, cc);
+		gui = go_gtk_builder_new ("gog-series-prefs.ui", GETTEXT_PACKAGE, cc);
 		if (gui != NULL) {
 			int i;
 			GogAxisSet set = gog_plot_axis_set_pref (gog_series_get_plot (series));
 			GogDataset *clamp_set = gog_series_get_interpolation_params (series);
-			widget = glade_xml_get_widget (gui, "interpolation_prefs");
+			widget = go_gtk_builder_get_widget (gui, "interpolation_prefs");
 			gtk_box_pack_start (GTK_BOX (box), widget, FALSE, FALSE, 0);
-			widget = glade_xml_get_widget (gui, "interpolation-table");
+			widget = go_gtk_builder_get_widget (gui, "interpolation-table");
 			/* create an interpolation type combo and populate it */
 			combo = GTK_COMBO_BOX (gtk_combo_box_new_text ());
 			if (set & 1 << GOG_AXIS_RADIAL)
@@ -558,7 +545,7 @@ gog_series_populate_editor (GogObject *gobj,
 					  0, 1, (GtkAttachOptions) (GTK_FILL | GTK_EXPAND),
 					  (GtkAttachOptions) (GTK_FILL | GTK_EXPAND), 0, 0);
 			gtk_widget_show_all (widget);
-			widget = glade_xml_get_widget (gui, "interpolation-skip-invalid");
+			widget = go_gtk_builder_get_widget (gui, "interpolation-skip-invalid");
 			g_object_set_data (G_OBJECT (combo), "skip-button", widget); 
 			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), series->interpolation_skip_invalid);
 			if (go_line_interpolation_auto_skip (series->interpolation))
@@ -567,7 +554,7 @@ gog_series_populate_editor (GogObject *gobj,
 					  G_CALLBACK (cb_line_interpolation_skip_changed), series);
 			if (clamp_set) {
 				GtkWidget *w;
-				widget = glade_xml_get_widget (gui, "clamps-table");
+				widget = go_gtk_builder_get_widget (gui, "clamps-table");
 				w = GTK_WIDGET (gog_data_allocator_editor (dalloc, clamp_set, 0, GOG_DATA_SCALAR));
 				gtk_widget_show (w);
 				gtk_table_attach (GTK_TABLE (widget), w, 1, 2, 0, 1, GTK_FILL | GTK_EXPAND, 0, 0, 0);
@@ -577,19 +564,18 @@ gog_series_populate_editor (GogObject *gobj,
 				if (series->interpolation != GO_LINE_INTERPOLATION_CLAMPED_CUBIC_SPLINE)
 					gtk_widget_hide (widget);
 			}
-			g_object_set_data_full (G_OBJECT (combo), "gui", gui,
-						(GDestroyNotify) g_object_unref);
+			g_signal_connect_swapped (G_OBJECT (combo), "destroy", G_CALLBACK (g_object_unref), gui);
 		}
 	}
 
 	box = go_editor_get_registered_widget (editor, "fill_extension_box");
 	if (series_class->has_fill_type && box != NULL) {
-		GladeXML *gui;
+		GtkBuilder *gui;
 		GtkWidget *widget;
 
-		gui = go_glade_new ("gog-series-prefs.glade", "fill_type_prefs", GETTEXT_PACKAGE, cc);
+		gui = go_gtk_builder_new ("gog-series-prefs.ui", GETTEXT_PACKAGE, cc);
 		if (gui != NULL) {
-			widget = glade_xml_get_widget (gui, "fill_type_combo");
+			widget = go_gtk_builder_get_widget (gui, "fill_type_combo");
 			gog_series_populate_fill_type_combo (GOG_SERIES (series), GTK_COMBO_BOX (widget));
 			g_signal_connect (G_OBJECT (widget), "changed",
 					  G_CALLBACK (cb_fill_type_changed), series);
@@ -597,7 +583,7 @@ gog_series_populate_editor (GogObject *gobj,
 				g_object_set_data (G_OBJECT (combo), "fill-type", widget);
 			if (series->interpolation == GO_LINE_INTERPOLATION_CLOSED_SPLINE)
 				gtk_widget_set_sensitive (widget, FALSE);
-			widget = glade_xml_get_widget (gui, "fill_type_prefs");
+			widget = go_gtk_builder_get_widget (gui, "fill_type_prefs");
 			gtk_box_pack_start (GTK_BOX (box), widget, TRUE, TRUE, 0);
 			g_object_set_data_full (G_OBJECT (widget), "gui", gui,
 						(GDestroyNotify) g_object_unref);
@@ -1083,23 +1069,22 @@ gog_series_get_xy_data (GogSeries const  *series,
 	GogSeriesClass	*klass = GOG_SERIES_GET_CLASS (series);
 	double *data[2];
 	unsigned int n_points;
+	int first, last;
 
 	g_return_val_if_fail (klass != NULL, 0);
 
 	if (klass->get_xy_data != NULL) {
-		int first, last;
-
 		if (!gog_series_is_valid (GOG_SERIES (series)))
 			return 0;
 
-		gog_dataset_dims (GOG_DATASET (series), &first, &last);
-
-		g_return_val_if_fail (first <= 0, 0);
-		g_return_val_if_fail (last >= 1, 0);
-
 		return (klass->get_xy_data) (series, x, y);
 	}
 
+	gog_dataset_dims (GOG_DATASET (series), &first, &last);
+
+	g_return_val_if_fail (first <= 0, 0);
+	g_return_val_if_fail (last >= 1, 0);
+
 	n_points = gog_series_get_data (series, NULL, data, 2);
 
 	*x = data[0];
