@@ -53,9 +53,9 @@ fmts_currency [] = {
 static char const *
 fmts_accounting [] = {
 	NULL, /* "_($* #,##0_);_($* (#,##0);_($* \"-\"_);_(@_)", */
-	"_(* #,##0_);_(* (#,##0);_(* \"-\"_);_(@_)",
+	NULL, /* "_(* #,##0_);_(* (#,##0);_(* \"-\"_);_(@_)", */
 	NULL, /* "_($* #,##0.00_);_($* (#,##0.00);_($* \"-\"??_);_(@_)", */
-	"_(* #,##0.00_);_(* (#,##0.00);_(* \"-\"??_);_(@_)",
+	NULL, /* "_(* #,##0.00_);_(* (#,##0.00);_(* \"-\"??_);_(@_)", */
 	NULL
 };
 
@@ -102,7 +102,7 @@ fmts_text [] = {
 
 /* Note: there is no entry for GO_FORMAT_UNKNOWN.  */
 char const * const * const
-go_format_builtins[] = {
+_go_format_builtins[] = {
 	fmts_general,
 	fmts_number,
 	fmts_currency,
@@ -194,69 +194,34 @@ guess_date_sep (void)
 }
 
 void
-go_currency_date_format_init (void)
+_go_currency_date_format_init (void)
 {
-	gboolean precedes, space_sep;
-	char const *curr = go_locale_get_currency (&precedes, &space_sep)->str;
-	char *pre, *post, *pre_rep, *post_rep;
+	GOFormatCurrency const *currency = go_format_locale_currency ();
 	GHashTable *dt_hash;
 	GOFormat *fmt;
 	guint N;
+	int i;
+	GOFormatDetails details;
 
-	/*
-	 *  1. "$*  "	Yes, it is needed (because we use match[])
-	 *  2. "$*  "	This one is like \1, but doesn't have the \{0,1\}
-	 *  3. "$"
-	 *  4. "#,##0.00"
-	 *  5. ".00"
-	 *  6. "*  $"	Same here.
-	 *  7. "*  $"
-	 *  8. "$"
-	 */
-
-	if (precedes) {
-		post_rep = post = (char *)"";
-		pre_rep = (char *)"* ";
-		pre = g_strconcat ("\"", curr,
-				   (space_sep ? "\" " : "\""), NULL);
-	} else {
-		pre_rep = pre = (char *)"";
-		post_rep = (char *)"* ";
-		post = g_strconcat ((space_sep ? " \"" : "\""),
-				    curr, "\"", NULL);
+	go_format_details_init (&details, GO_FORMAT_CURRENCY);
+	details.currency = currency;
+	for (i = 0; i < 6; i++) {
+		GString *str = g_string_new (NULL);
+		details.num_decimals = (i >= 3) ? 2 : 0;
+		details.negative_red = (i % 3 == 2);
+		details.negative_paren = (i % 3 >= 1);
+		go_format_generate_str (str, &details);
+		fmts_currency[i] = g_string_free (str, FALSE);
 	}
 
-	fmts_currency [0] = g_strdup_printf (
-		"%s#,##0%s",
-		pre, post);
-	fmts_currency [1] = g_strdup_printf (
-		"%s#,##0%s_);(%s#,##0%s)",
-		pre, post, pre, post);
-	fmts_currency [2] = g_strdup_printf (
-		"%s#,##0%s_);[Red](%s#,##0%s)",
-		pre, post, pre, post);
-	fmts_currency [3] = g_strdup_printf (
-		"%s#,##0.00%s",
-		pre, post);
-	fmts_currency [4] = g_strdup_printf (
-		"%s#,##0.00%s_);(%s#,##0.00%s)",
-		pre, post, pre, post);
-	fmts_currency [5] = g_strdup_printf (
-		"%s#,##0.00%s_);[Red](%s#,##0.00%s)",
-		pre, post, pre, post);
-
-	fmts_accounting [0] = g_strdup_printf (
-		"_(%s%s#,##0%s%s_);_(%s%s(#,##0)%s%s;_(%s%s\"-\"%s%s_);_(@_)",
-		pre, pre_rep, post_rep, post,
-		pre, pre_rep, post_rep, post,
-		pre, pre_rep, post_rep, post);
-	fmts_accounting [2] = g_strdup_printf (
-		"_(%s%s#,##0.00%s%s_);_(%s%s(#,##0.00)%s%s;_(%s%s\"-\"??%s%s_);_(@_)",
-		pre, pre_rep, post_rep, post,
-		pre, pre_rep, post_rep, post,
-		pre, pre_rep, post_rep, post);
-
-	g_free (*pre ? pre : post);
+	go_format_details_init (&details, GO_FORMAT_ACCOUNTING);
+	for (i = 0; i < 4; i++) {
+		GString *str = g_string_new (NULL);
+		details.num_decimals = (i >= 2) ? 2 : 0;
+		details.currency = (i & 1) ? NULL : currency;
+		go_format_generate_str (str, &details);
+		fmts_accounting[i] = g_string_free (str, FALSE);
+	}
 
 	/* ---------------------------------------- */
 
@@ -348,7 +313,7 @@ go_currency_date_format_init (void)
 }
 
 void
-go_currency_date_format_shutdown (void)
+_go_currency_date_format_shutdown (void)
 {
 	/* We need to free allocated strings since */
 	/* currency_date_format_init/shutdown may  */
@@ -358,13 +323,14 @@ go_currency_date_format_shutdown (void)
 	int i;
 
 	for (i = 0; i < 6; i++) {
-		g_free ((char *)(fmts_currency [i]));
-		fmts_currency [i] = NULL;
+		g_free ((char *)(fmts_currency[i]));
+		fmts_currency[i] = NULL;
+	}
+
+	for (i = 0; i < 4; i++) {
+		g_free ((char *)(fmts_accounting[i]));
+		fmts_accounting[i] = NULL;
 	}
-	g_free ((char *)(fmts_accounting[0]));
-	fmts_accounting [0] = NULL;
-	g_free ((char *)(fmts_accounting[2]));
-	fmts_accounting[2] = NULL;
 
 	for (i = 0; fmts_date[i]; i++) {
 		g_free ((char*)(fmts_date[i]));
@@ -377,7 +343,7 @@ go_currency_date_format_shutdown (void)
 	}
 }
 
-GOFormatCurrency const go_format_currencies[] =
+GOFormatCurrency const _go_format_currencies[] =
 {
  	{ "", N_("None"), TRUE, FALSE },	/* These first six elements */
  	{ "$", "$", TRUE, FALSE },		/* Must stay in this order */
