@@ -21,12 +21,7 @@
 #ifndef GO_FONT_H
 #define GO_FONT_H
 
-#include <glib.h>
 #include <goffice/goffice.h>
-#include <goffice/goffice-features.h>
-#include <goffice/utils/goffice-utils.h>
-#include <pango/pango-font.h>
-#include <pango/pango-context.h>
 
 G_BEGIN_DECLS
 
@@ -80,8 +75,8 @@ void go_font_cache_register   (GClosure *callback);
 void go_font_cache_unregister (GClosure *callback);
 
 /* private */
-void go_fonts_init     (void);
-void go_fonts_shutdown (void);
+void _go_fonts_init     (void);
+void _go_fonts_shutdown (void);
 
 G_END_DECLS
 
