@@ -159,7 +159,7 @@ go_pattern_get_svg_path (GOPattern const *pattern, double *width, double *height
 	xmlDocPtr  doc;
 	xmlNodePtr ptr;
 
-	g_return_val_if_fail (pattern->pattern >= 0 || pattern->pattern < GO_PATTERN_MAX, NULL);
+	g_return_val_if_fail (pattern->pattern < GO_PATTERN_MAX, NULL);
 
 	path = g_build_filename (go_sys_data_dir(), "patterns", "svg-patterns.xml", NULL);
 	doc = go_xml_parse_file (path);
@@ -175,13 +175,16 @@ go_pattern_get_svg_path (GOPattern const *pattern, double *width, double *height
 		    ptr->name &&
 		    !strcmp ((char *)ptr->name, "pattern"))
 		{
+			double value;
 			name = xmlGetProp (ptr, CC2XML ("name"));
 			if (name != NULL) {
 				if (strcmp ((char *)name, go_patterns [pattern->pattern].str) == 0) {
-					if (width != NULL)
-						xml_node_get_double (ptr, "width", width);
-					if (height != NULL)
-						xml_node_get_double (ptr, "height", height);
+					if (width != NULL && 
+						go_xml_node_get_double (ptr, "width", &value))
+					    *width = value;
+					if (height != NULL &&
+						go_xml_node_get_double (ptr, "height", &value))
+					    *height = value;
 					svg_path = xmlGetProp (ptr, CC2XML ("d"));
 					break;
 				}
